@@ -31,7 +31,7 @@ class KGpgKeyserverTransaction: public KGpgTransaction {
 	/**
 	 * @brief forbidden
 	 */
-	KGpgKeyserverTransaction() Q_DECL_EQ_DELETE;
+	KGpgKeyserverTransaction() = delete;
 protected:
 	/**
 	 * @brief construct a new transaction for the given keyserver
@@ -69,8 +69,8 @@ public:
 	void setProgressEnable(const bool b);
 
 protected:
-	void finish() Q_DECL_OVERRIDE;
-	bool preStart() Q_DECL_OVERRIDE;
+	void finish() override;
+	bool preStart() override;
 
 private slots:
 	/**
