@@ -31,7 +31,7 @@ class KGpgVerify: public KGpgTextOrFileTransaction {
 	Q_OBJECT
 
 	Q_DISABLE_COPY(KGpgVerify)
-	KGpgVerify() Q_DECL_EQ_DELETE;
+	KGpgVerify() = delete;
 public:
 	enum ts_verify {
 		TS_MISSING_KEY = KGpgTransaction::TS_COMMON_END + 1,	///< signing key not in keyring
@@ -75,9 +75,9 @@ public:
 	QString missingId() const;
 
 protected:
-	QStringList command() const Q_DECL_OVERRIDE;
-	bool nextLine(const QString &line) Q_DECL_OVERRIDE;
-	void finish() Q_DECL_OVERRIDE;
+	QStringList command() const override;
+	bool nextLine(const QString &line) override;
+	void finish() override;
 
 private:
 	int m_fileIndex;
